@@ -107,6 +107,10 @@ class Application(ABC):
         self.on_init()
         self.init_features()
 
+    async def do_sleep(self):
+        while True:
+            await asyncio.sleep(3600)
+
     def run(self):
         self.logger.info('Application started')
         features: List[AppFeature] = []
@@ -123,6 +127,12 @@ class Application(ABC):
                 break
             features.append(ft)
 
+        try:
+            self._task = self.loop.create_task(self.do_sleep())
+            self.loop.run_until_complete(self._task)
+        except asyncio.CancelledError:
+            pass
+
         for ft in reversed(features):
             self.logger.info('Shutdown feature %s', ft.name)
             self._task = self.loop.create_task(ft.on_shutdown())
