@@ -39,14 +39,14 @@ class Config:
 
     def process_env(self, env_prefix: str):
         """
-        Scan environment variables and enrich config by deconstructing it's path.
-        Example: `APP_WEB_PORT`'s value will be written into config by path `web.port`
+        Scan environment variables and enrich config by deconstructing its path.
+        Example: `APP_WEB__PORT`'s value will be written into config by path `web.port`
         :param env_prefix: prefix to filter out variables. Default is `APP`
         """
         for e in os.environ:
             if e.startswith(env_prefix):
                 entry_value = os.environ.get(e)
-                entry_path = e.lower().split('_')[1:]
+                entry_path = e.lower().split('__')[1:]
 
                 path = self.config
                 entry_path_len = len(entry_path)
